# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LogLevelEnum(str, Enum):
    """
    LogLevelEnum
    """

    """
    allowed enum values
    """
    CRITICAL = 'critical'
    EXCEPTION = 'exception'
    ERROR = 'error'
    WARN = 'warn'
    WARNING = 'warning'
    INFO = 'info'
    DEBUG = 'debug'
    NOTSET = 'notset'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LogLevelEnum from a JSON string"""
        return cls(json.loads(json_str))


